==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property fileSystemId The ID of the file system, assigned by Amazon EFS.
 * @property path The pathname for the folder being used by a workflow.
 */
public data class
WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs(
    public val fileSystemId: Output<String>? = null,
    public val path: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.transfer.inputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs> {
    override fun toJava():
        com.pulumi.aws.transfer.inputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs =
        com.pulumi.aws.transfer.inputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.builder()
            .fileSystemId(fileSystemId?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs].
 */
@PulumiTagMarker
public class
WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgsBuilder
internal constructor() {
    private var fileSystemId: Output<String>? = null

    private var path: Output<String>? = null

    /**
     * @param value The ID of the file system, assigned by Amazon EFS.
     */
    @JvmName("bwocatmjfywbqtxg")
    public suspend fun fileSystemId(`value`: Output<String>) {
        this.fileSystemId = value
    }

    /**
     * @param value The pathname for the folder being used by a workflow.
     */
    @JvmName("ehcvurkpymsmtuvb")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The ID of the file system, assigned by Amazon EFS.
     */
    @JvmName("nlmkiuleqjcvybpy")
    public suspend fun fileSystemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystemId = mapped
    }

    /**
     * @param value The pathname for the folder being used by a workflow.
     */
    @JvmName("sicylkydhvmdhbnp")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    internal fun build():
        WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs =
        WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs(
            fileSystemId = fileSystemId,
            path = path,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/transfer/kotlin/inputs/WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.transfer.kotlin.inputs

import com.pulumi.aws.transfer.inputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property fileSystemId The ID of the file system, assigned by Amazon EFS.
 * @property path The pathname for the folder being used by a workflow.
 */
public data class
WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs(
    public val fileSystemId: Output<String>? = null,
    public val path: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.transfer.inputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs> {
    override fun toJava(): com.pulumi.aws.transfer.inputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs =
        com.pulumi.aws.transfer.inputs.WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs.builder()
            .fileSystemId(fileSystemId?.applyValue({ args0 -> args0 }))
            .path(path?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs].
 */
@PulumiTagMarker
public class
WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgsBuilder
internal constructor() {
    private var fileSystemId: Output<String>? = null

    private var path: Output<String>? = null

    /**
     * @param value The ID of the file system, assigned by Amazon EFS.
     */
    @JvmName("wotcsqtjhcutwjvt")
    public suspend fun fileSystemId(`value`: Output<String>) {
        this.fileSystemId = value
    }

    /**
     * @param value The pathname for the folder being used by a workflow.
     */
    @JvmName("txiccpniyepbnmwt")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The ID of the file system, assigned by Amazon EFS.
     */
    @JvmName("bpfqlcrjmjwwpnmq")
    public suspend fun fileSystemId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileSystemId = mapped
    }

    /**
     * @param value The pathname for the folder being used by a workflow.
     */
    @JvmName("cipqsjpxsnrmfkcy")
    public suspend fun path(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.path = mapped
    }

    internal fun build(): WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs =
        WorkflowOnExceptionStepDecryptStepDetailsDestinationFileLocationEfsFileLocationArgs(
            fileSystemId = fileSystemId,
            path = path,
        )
}
